@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"log"
 	"os"
+	"runtime/debug"
 
 	"filippo.io/age"
 	"filippo.io/age/plugin"
@@ -19,6 +20,10 @@ implementation of age that supports plugins.
 Usually, tagged recipients are the public side of private keys held in hardware,
 where the identity side is handled by a different plugin.`
 
+// Version can be set at link time to override debug.BuildInfo.Main.Version when
+// building manually without git history. It should look like "v1.2.3".
+var Version string
+
 func main() {
 	flag.Usage = func() { fmt.Fprintf(os.Stderr, "%s\n", usage) }
 
@@ -26,8 +31,22 @@ func main() {
 	if err != nil {
 		log.Fatal(err)
 	}
+	p.RegisterFlags(nil)
+
+	versionFlag := flag.Bool("version", false, "print the version")
+	flag.Parse()
+
+	if *versionFlag {
+		if buildInfo, ok := debug.ReadBuildInfo(); ok && Version == "" {
+			Version = buildInfo.Main.Version
+		}
+		fmt.Println(Version)
+		return
+	}
+
 	p.HandleRecipient(func(b []byte) (age.Recipient, error) {
 		return tag.NewHybridRecipient(b)
 	})
+
 	os.Exit(p.Main())
 }
